import { v4 as uuidv4 } from "uuid"
import type { Simulation } from "./debutant"

const expertSimulations: Simulation[] = [
  {
    id: uuidv4(),
    title: "Simulation expert #1",
    description: "Première simulation pour les conducteurs de niveau expert",
    duration: 35,
    questions: [
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le dépassement d'un véhicule de transport en commun à l'arrêt ?",
        options: [
          "Interdit si les passagers montent ou descendent",
          "Autorisé en roulant au pas",
          "Interdit dans tous les cas",
          "Autorisé en klaxonnant",
        ],
        correctAnswer: "Interdit si les passagers montent ou descendent",
        explanation:
          "Il est interdit de dépasser un véhicule de transport en commun à l'arrêt lorsque les passagers montent ou descendent. Si aucun passager ne monte ou ne descend, le dépassement est autorisé à allure modérée.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation des feux antibrouillard avant ?",
        options: [
          "Obligatoire par temps de pluie",
          "Autorisée uniquement par brouillard ou chute de neige",
          "Autorisée de nuit sur route non éclairée",
          "Interdite en agglomération",
        ],
        correctAnswer: "Autorisée uniquement par brouillard ou chute de neige",
        explanation:
          "Les feux antibrouillard avant peuvent être utilisés uniquement en cas de brouillard ou de chute de neige. Leur utilisation est interdite par temps clair car ils peuvent éblouir les autres usagers.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le stationnement en double file ?",
        options: [
          "Autorisé pour une courte durée",
          "Autorisé si les feux de détresse sont allumés",
          "Interdit sauf pour les véhicules de livraison",
          "Interdit dans tous les cas",
        ],
        correctAnswer: "Interdit dans tous les cas",
        explanation:
          "Le stationnement en double file est strictement interdit, même pour une courte durée et même avec les feux de détresse allumés. Il constitue une gêne importante pour la circulation.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation de la voie du milieu sur une autoroute à trois voies ?",
        options: [
          "Réservée aux dépassements",
          "Utilisable pour circuler normalement",
          "Réservée aux véhicules lents",
          "Réservée aux véhicules rapides",
        ],
        correctAnswer: "Utilisable pour circuler normalement",
        explanation:
          "Sur une autoroute à trois voies, la voie du milieu peut être utilisée pour circuler normalement. La voie de gauche est réservée aux dépassements, et on doit se rabattre à droite lorsque c'est possible.",
      },
      {
        id: uuidv4(),
        question:
          "Quelle est la règle concernant le franchissement d'un passage à niveau dont les barrières sont en train de s'abaisser ?",
        options: [
          "Autorisé si on peut passer rapidement",
          "Autorisé si aucun train n'est visible",
          "Interdit dans tous les cas",
          "Autorisé si les feux ne clignotent pas encore",
        ],
        correctAnswer: "Interdit dans tous les cas",
        explanation:
          "Il est strictement interdit de s'engager sur un passage à niveau lorsque les barrières sont en mouvement (descente ou montée) ou lorsque les feux rouges clignotent, même si aucun train n'est visible.",
      },
    ],
  },
  {
    id: uuidv4(),
    title: "Simulation expert #2",
    description: "Deuxième simulation pour les conducteurs de niveau expert",
    duration: 35,
    questions: [
      {
        id: uuidv4(),
        question:
          "Quelle est la règle concernant l'utilisation de la voie d'accélération pour entrer sur une autoroute ?",
        options: [
          "S'arrêter au début et attendre un espace",
          "Rouler à vitesse constante et s'insérer",
          "Accélérer pour atteindre la vitesse du trafic et s'insérer",
          "Ralentir pour laisser passer les véhicules",
        ],
        correctAnswer: "Accélérer pour atteindre la vitesse du trafic et s'insérer",
        explanation:
          "La voie d'accélération doit être utilisée pour atteindre progressivement la vitesse du trafic circulant sur l'autoroute, ce qui facilite l'insertion sans perturber la circulation.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le dépassement d'un véhicule agricole ?",
        options: [
          "Interdit hors agglomération",
          "Autorisé même en présence d'une ligne continue",
          "Soumis aux mêmes règles que tout autre dépassement",
          "Autorisé uniquement par la droite",
        ],
        correctAnswer: "Soumis aux mêmes règles que tout autre dépassement",
        explanation:
          "Le dépassement d'un véhicule agricole est soumis aux mêmes règles que tout autre dépassement : il est interdit sur une ligne continue, dans un virage sans visibilité, etc.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation du régulateur de vitesse par temps de pluie ?",
        options: [
          "Recommandée pour maintenir une vitesse constante",
          "Obligatoire sur autoroute",
          "Déconseillée car elle réduit la vigilance",
          "Interdite car dangereuse",
        ],
        correctAnswer: "Déconseillée car elle réduit la vigilance",
        explanation:
          "L'utilisation du régulateur de vitesse est déconseillée par temps de pluie car elle peut réduire la vigilance du conducteur et l'adaptation de la vitesse aux conditions changeantes de la route.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le stationnement sur une place réservée aux personnes handicapées ?",
        options: [
          "Autorisé pour une courte durée",
          "Autorisé la nuit",
          "Autorisé si aucune personne handicapée n'est présente",
          "Strictement interdit sans carte de stationnement appropriée",
        ],
        correctAnswer: "Strictement interdit sans carte de stationnement appropriée",
        explanation:
          "Le stationnement sur une place réservée aux personnes handicapées est strictement interdit sans la carte européenne de stationnement ou la carte mobilité inclusion (CMI) comportant la mention 'stationnement'.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation du frein à main lors d'un stationnement en pente ?",
        options: [
          "Facultative si une vitesse est enclenchée",
          "Obligatoire dans tous les cas",
          "Facultative si les roues sont braquées",
          "Obligatoire uniquement si la pente est forte",
        ],
        correctAnswer: "Obligatoire dans tous les cas",
        explanation:
          "L'utilisation du frein à main (frein de stationnement) est obligatoire lors de tout stationnement, particulièrement en pente. Il doit être complété par l'engagement d'une vitesse et le braquage des roues vers le trottoir.",
      },
    ],
  },
]

export default expertSimulations
